@@ -32,6 +32,6 @@ CREATE CAST (bigint AS h3index) WITH FUNCTION bigint_to_h3index(bigint);
 COMMENT ON CAST (h3index AS bigint) IS
     'Convert bigint to H3 index.';
 
-CREATE CAST (h3index AS point) WITH FUNCTION h3_cell_to_lat_lng(h3index);
+CREATE CAST (h3index AS point) WITH FUNCTION h3_cell_to_latlng(h3index);
 COMMENT ON CAST (h3index AS point) IS
     'Convert H3 index to point.';
\ No newline at end of file
