@@ -19,31 +19,31 @@
 --| Using other SRIDs, such as 3857, can result in either errors or
 --| invalid data depending on the function.
 --| For example, the `h3_polygon_to_cells()` function will fail with
---| an error in this scenario while the `h3_lat_lng_to_cell()` function
+--| an error in this scenario while the `h3_latlng_to_cell()` function
 --| will return an invalid geometry.
 
 --| # PostGIS Indexing Functions
 
---@ availability: 4.0.0
---@ refid: h3_lat_lng_to_cell_geometry
-CREATE OR REPLACE FUNCTION h3_lat_lng_to_cell(geometry, resolution integer) RETURNS h3index
-    AS $$ SELECT h3_lat_lng_to_cell($1::point, $2); $$ IMMUTABLE STRICT PARALLEL SAFE LANGUAGE SQL;
+--@ availability: 4.2.3
+--@ refid: h3_latlng_to_cell_geometry
+CREATE OR REPLACE FUNCTION h3_latlng_to_cell(geometry, resolution integer) RETURNS h3index
+    AS $$ SELECT h3_latlng_to_cell($1::point, $2); $$ IMMUTABLE STRICT PARALLEL SAFE LANGUAGE SQL;
 COMMENT ON FUNCTION
-    h3_lat_lng_to_cell(geometry, resolution integer)
+    h3_latlng_to_cell(geometry, resolution integer)
 IS 'Indexes the location at the specified resolution.';
 
---@ availability: 4.0.0
---@ refid: h3_lat_lng_to_cell_geography
-CREATE OR REPLACE FUNCTION h3_lat_lng_to_cell(geography, resolution integer) RETURNS h3index
-    AS $$ SELECT h3_lat_lng_to_cell($1::geometry, $2); $$ IMMUTABLE STRICT PARALLEL SAFE LANGUAGE SQL;
+--@ availability: 4.2.3
+--@ refid: h3_latlng_to_cell_geography
+CREATE OR REPLACE FUNCTION h3_latlng_to_cell(geography, resolution integer) RETURNS h3index
+    AS $$ SELECT h3_latlng_to_cell($1::geometry, $2); $$ IMMUTABLE STRICT PARALLEL SAFE LANGUAGE SQL;
 COMMENT ON FUNCTION
-    h3_lat_lng_to_cell(geometry, resolution integer)
+    h3_latlng_to_cell(geometry, resolution integer)
 IS 'Indexes the location at the specified resolution.';
 
 --@ availability: 4.0.0
 --@ refid: h3_cell_to_geometry
 CREATE OR REPLACE FUNCTION h3_cell_to_geometry(h3index) RETURNS geometry
-  AS $$ SELECT ST_SetSRID(h3_cell_to_lat_lng($1)::geometry, 4326) $$ IMMUTABLE STRICT PARALLEL SAFE LANGUAGE SQL;
+  AS $$ SELECT ST_SetSRID(h3_cell_to_latlng($1)::geometry, 4326) $$ IMMUTABLE STRICT PARALLEL SAFE LANGUAGE SQL;
 COMMENT ON FUNCTION
     h3_cell_to_geometry(h3index)
 IS 'Finds the centroid of the index.';
@@ -75,3 +75,35 @@ COMMENT ON FUNCTION
 IS 'Finds the boundary of the index.
 
 Splits polygons when crossing 180th meridian.';
+
+--@ availability: 4.2.3
+--@ refid: h3_get_resolution_from_tile_zoom
+CREATE OR REPLACE FUNCTION h3_get_resolution_from_tile_zoom(
+    z integer,
+    max_h3_resolution integer DEFAULT 15,
+    min_h3_resolution integer DEFAULT 0,
+    hex_edge_pixels integer DEFAULT 44,
+    tile_size integer DEFAULT 512
+) RETURNS integer
+AS $$
+DECLARE
+    e0  CONSTANT numeric := h3_get_hexagon_edge_length_avg(0,'m'); -- res-0 edge
+    ln7 CONSTANT numeric := LN(SQRT(7.0));                         -- = ln(√7)
+    desired_edge numeric;
+    r_est        integer;
+BEGIN
+    IF z < 0 THEN
+        RAISE EXCEPTION 'Negative tile zoom levels are not supported';
+    END IF;
+
+    desired_edge := 40075016.6855785 / (tile_size * 2 ^ z) * hex_edge_pixels;
+
+    r_est := ROUND( LN(e0 / desired_edge) / ln7 );
+
+    RETURN GREATEST(min_h3_resolution,
+           LEAST(r_est, max_h3_resolution));
+END;
+$$ LANGUAGE plpgsql IMMUTABLE STRICT PARALLEL SAFE;
+COMMENT ON FUNCTION
+    h3_get_resolution_from_tile_zoom(integer, integer, integer, integer, integer)
+IS 'Returns the optimal H3 resolution for a specified XYZ tile zoom level, based on hexagon size in pixels and resolution limits';
