@@ -23,3 +23,19 @@ CREATE OR REPLACE FUNCTION h3_cell_to_boundary_geometry(h3index, extend_antimeri
 --@ deprecated
 CREATE OR REPLACE FUNCTION h3_cell_to_boundary_geography(h3index, extend_antimeridian boolean) RETURNS geography
   AS $$ SELECT ST_SetSRID(h3_cell_to_boundary($1, extend_antimeridian)::geometry, 4326) $$ IMMUTABLE STRICT PARALLEL SAFE LANGUAGE SQL;
+
+--@ availability: 4.0.0
+--@ deprecated
+CREATE OR REPLACE FUNCTION h3_lat_lng_to_cell(geometry, resolution integer) RETURNS h3index
+    AS $$ SELECT h3_lat_lng_to_cell($1::point, $2); $$ IMMUTABLE STRICT PARALLEL SAFE LANGUAGE SQL;
+COMMENT ON FUNCTION
+    h3_lat_lng_to_cell(geometry, resolution integer)
+IS 'DEPRECATED: Use `h3_latlng_to_cell` instead..';
+
+--@ availability: 4.0.0
+--@ deprecated
+CREATE OR REPLACE FUNCTION h3_lat_lng_to_cell(geography, resolution integer) RETURNS h3index
+    AS $$ SELECT h3_lat_lng_to_cell($1::geometry, $2); $$ IMMUTABLE STRICT PARALLEL SAFE LANGUAGE SQL;
+COMMENT ON FUNCTION
+    h3_lat_lng_to_cell(geometry, resolution integer)
+IS 'DEPRECATED: Use `h3_latlng_to_cell` instead..';
\ No newline at end of file
